==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24LightWeightPopup.h <==
// class javax.swing.JPopupMenu$LightWeightPopup

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2389f1a2ed16e234 javax_swing_JPopupMenu__24LightWeightPopup

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$refs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object	_jc_javax_swing_JPopupMenu__24LightWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *);
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24LightWeightPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JPopupMenu__24LightWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *);
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods	javax_swing_JPopupMenu__24LightWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs {
	struct _jc_java_awt_Component$object	*c;
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs	javax_swing_JPopupMenu__24LightWeightPopup;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24LightWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype _jc_javax_swing_JPopupMenu__24LightWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24LightWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24LightWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24LightWeightPopup.h <==
// class javax.swing.JPopupMenu$LightWeightPopup

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2389f1a2ed16e234 javax_swing_JPopupMenu__24LightWeightPopup

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_
#define _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$refs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$refs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs	_jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object	_jc_javax_swing_JPopupMenu__24LightWeightPopup$object;

typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$_init$0ad2bcb8655c238d(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, struct _jc_javax_swing_JPopupMenu$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JPopupMenu__24LightWeightPopup$method$show$9d69c93242b99fe6(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24LightWeightPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JPopupMenu__24LightWeightPopup$method_info$show$9d69c93242b99fe6;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *) _JC_JCNI_ATTR;
	void	(*show$9d69c93242b99fe6)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vmethods	javax_swing_JPopupMenu__24LightWeightPopup;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs {
	struct _jc_java_awt_Component$object	*c;
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$refs {
    _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_refs	javax_swing_JPopupMenu__24LightWeightPopup;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JPopupMenu__24LightWeightPopup$sub_nonrefs	javax_swing_JPopupMenu__24LightWeightPopup;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24LightWeightPopup$object {
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24LightWeightPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24LightWeightPopup$vtype _jc_javax_swing_JPopupMenu__24LightWeightPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24LightWeightPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24LightWeightPopup$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24LightWeightPopup_H_ */
